# Profile

## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**email_address** | **str** | The user&#x27;s email address. | [optional] 
**history_id** | **str** | The ID of the mailbox&#x27;s current history record. | [optional] 
**messages_total** | **int** | The total number of messages in the mailbox. | [optional] 
**threads_total** | **int** | The total number of threads in the mailbox. | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)

